==> stew-3.0.0-beta2.zip: Stew/src/net/argius/stew/ui/window/Resource.java <==
/*
 *  Copyright 2010 argius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package net.argius.stew.ui.window;

import java.awt.*;
import java.io.*;
import java.text.*;
import java.util.*;

import javax.swing.*;

import net.argius.stew.*;

/**
 * \[XB
 */
final class Resource {

    /** 󕶎 */
    static final String EMPTY_STRING = "";

    /** s(Swing/AWTłCRLF𐳂łȂ) */
    static final String EOL = "\n";

    /** ^u */
    static final String TAB = "\t";

    private static final String BUNDLE_NAME = Resource.class.getPackage().getName() + ".messages";
    private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BUNDLE_NAME);

    private Resource() {
        // empty
    }

    /**
     * O̎擾B
     * @param key L[
     * @param args p[^
     * @return 
     */
    static String getString(String key, Object... args) {
        try {
            String s = RESOURCE_BUNDLE.getString(key);
            if (args.length == 0) {
                return s;
            }
            return MessageFormat.format(s, args);
        } catch (MissingResourceException e) {
            return String.format("?(%s,%s)", key, Arrays.asList(args));
        }
    }

    /**
     * ACR̎擾B
     * @param name \[X
     * @return ACR
     */
    static ImageIcon getImageIcon(String name) {
        try {
            return new ImageIcon(Resource.class.getResource(name));
        } catch (RuntimeException ex) {
            return new ImageIcon();
        }
    }

    /**
     * j[̃V[gJbgL[MASKl̎擾B
     * j[ŎgpvȃV[gJbgL[̏CL[
     * vbgtH[ɈˑiMacOS̓R}hL[AWindowsCtrlL[AȂǁj
     * 邽߁A̒lgpB
     * @return V[gJbgL[MASKl
     */
    static int getMenuShortcutKeyMask() {
        return Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
    }

    /**
     * o[W̎擾B
     * @return o[W
     */
    static String getVersion() {
        InputStream is = LocalSystem.class.getResourceAsStream("version");
        try {
            Scanner scanner = new Scanner(is);
            return scanner.nextLine();
        } finally {
            try {
                is.close();
            } catch (IOException ex) {
                throw new RuntimeException(ex);
            }
        }
    }

}

==> stew-3.3.0-beta2.zip: Stew/src/net/argius/stew/ui/window/Resource.java <==
/*
 *  Copyright 2010 argius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package net.argius.stew.ui.window;

import java.awt.*;

import javax.swing.*;

import net.argius.stew.*;

/**
 * \[XB
 */
final class Resource {

    /** 󕶎 */
    static final String EMPTY_STRING = "";

    /** s(Swing/AWTłCRLF𐳂łȂ) */
    static final String EOL = "\n";

    /** ^u */
    static final String TAB = "\t";

    private static final ResourceManager res = ResourceManager.getInstance(Resource.class);

    private Resource() {
        // empty
    }

    /**
     * O̎擾B
     * @param key L[
     * @param args p[^
     * @return 
     */
    static String getString(String key, Object... args) {
        return res.get(key, args);
    }

    /**
     * ACR̎擾B
     * @param name \[X
     * @return ACR
     */
    static ImageIcon getImageIcon(String name) {
        try {
            return new ImageIcon(Resource.class.getResource("icon/" + name));
        } catch (RuntimeException ex) {
            return new ImageIcon();
        }
    }

    /**
     * j[̃V[gJbgL[MASKl̎擾B
     * j[ŎgpvȃV[gJbgL[̏CL[
     * vbgtH[ɈˑiMacOS̓R}hL[AWindowsCtrlL[AȂǁj
     * 邽߁A̒lgpB
     * @return V[gJbgL[MASKl
     */
    static int getMenuShortcutKeyMask() {
        return Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
    }

    /**
     * o[W̎擾B
     * @return o[W
     */
    static String getVersion() {
        return LocalSystem.getVersion();
    }

}
